## START: Set by rpmautospec
## (rpmautospec version 0.8.1)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond check 1

# We don’t use go macros to build, but this is what they do to prevent binutils-style-ld flags to
# mess things up for the Go linker.
%undefine _auto_set_build_flags

%global goipath forgejo.org

Name:           forgejo
Version:        11.0.0
Release:        %autorelease
Summary:        A lightweight software forge

# Forgejo itself is "MIT AND GPL-3.0-or-later", the following is the combination with vendored
# sources.
# CC0-1.0 is normally not permissible for code in Fedora. Because the vendored Go package
# github.com/zeebo/blake3 it applies to has been available in Fedora as golang-github-zeebo-blake3
# since before the cutoff date 2022-08-01, the exception to use it also applies here.
License:        Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND GPL-3.0-or-later AND ICU AND ISC AND LicenseRef-Fedora-Public-Domain AND MIT AND MPL-2.0 AND (FTL OR GPL-2.0-or-later)
URL:            https://codeberg.org/forgejo/forgejo
%global         src_tarball %{url}/releases/download/v%{version}/%{name}-src-%{version}.tar.gz
Source0:        %{src_tarball}
Source1:        %{src_tarball}.asc
Source2:        https://openpgpkey.forgejo.org/.well-known/openpgpkey/forgejo.org/hu/dj3498u4hyyarh35rkjfnghbjxug6b19#/dj3498u4hyyarh35rkjfnghbjxug6b19.pgp
Source3:        go-vendor-tools.toml
Source4:        robots.txt
Source5:        forgejo.service
Source6:        forgejo-init.service
Source7:        forgejo-init.sh
Source8:        forgejo.sysusers.conf
Source9:        forgejo.sysconfig

Patch0:         forgejo-10.0.1-app.ini.tmpl.patch

ExclusiveArch:  %golang_arches_future

BuildRequires:  coreutils
BuildRequires:  gnupg2
BuildRequires:  go-rpm-macros
BuildRequires:  golang-bin >= 1.23
BuildRequires:  golang-src >= 1.23
BuildRequires:  go-vendor-tools
BuildRequires:  go-vendor-tools+scancode
BuildRequires:  make
BuildRequires:  nodejs >= 20
BuildRequires:  sed
BuildRequires:  sqlite-devel
BuildRequires:  systemd-rpm-macros

Requires:       bash
Requires:       coreutils
Requires:       git-core
Requires:       git-lfs
Requires:       sed
%{?sysusers_requires_compat}

%description
Forgejo is a lightweight software forge. Use it to host git repositories, track their issues and
allow people to contribute to them!

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -N -n %{name}-src-%{version}

patch --input=%{PATCH0} --output=app.ini.tmpl custom/conf/app.example.ini


%generate_buildrequires
%go_vendor_license_buildrequires -c %{S:3}


%build
# Build manually rather than using the Makefile, so globally defined flags are applied.
%global gomodulesmode GO111MODULE=on
%global gotags bindata timetzdata sqlite sqlite_unlock_notify
%global gobuildflags %{?gobuildflags} -tags '%gotags'
go generate -tags '%gotags' ./...
export GO_LDFLAGS=" \
    -X \"forgejo.org/modules/setting.CustomPath=%{_sysconfdir}/%{name}\" \
    -X \"forgejo.org/modules/setting.CustomConf=%{_sysconfdir}/%{name}/conf/app.ini\" \
    -X \"forgejo.org/modules/setting.AppWorkPath=%{_sharedstatedir}/%{name}\" \
    -X \"main.Tags=%{gotags}\" \
    -X \"main.ReleaseVersion=%{version}-%{release}\" \
    -X \"main.Version=%{version}-%{release}\" \
"
%gobuild -o forgejo %{goipath}

sed -e 's/gitea/%{name}/g' \
    < contrib/autocompletion/bash_autocomplete \
    > %{name}.complete
touch -r contrib/autocompletion/bash_autocomplete %{name}.complete

%install
%go_vendor_license_install -c %{S:3}
install -m755 -D %{name} %{buildroot}%{_bindir}/%{name}

install -m755 -d \
    %{buildroot}%{_sysconfdir}/%{name}/conf \
    %{buildroot}%{_sysconfdir}/%{name}/public/assets \
    %{buildroot}%{_sysconfdir}/%{name}/templates

install -m644 -p -D app.ini.tmpl %{buildroot}%{_sysconfdir}/%{name}/conf/app.ini.tmpl
install -m644 -p -D %{S:4} %{buildroot}%{_sysconfdir}/%{name}/public/robots.txt
install -m644 -p -D %{name}.complete %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -m644 -p -D %{S:5} %{buildroot}%{_unitdir}/%{name}.service
install -m644 -p -D %{S:6} %{buildroot}%{_unitdir}/%{name}-init.service
install -m755 -p -D %{S:7} %{buildroot}%{_libexecdir}/%{name}-init
install -m644 -p -D %{S:8} %{buildroot}%{_sysusersdir}/%{name}.conf

install -m750 -d \
    %{buildroot}%{_sharedstatedir}/%{name} \
    %{buildroot}%{_sharedstatedir}/%{name}/data \
    %{buildroot}%{_sharedstatedir}/%{name}/log

install -m640 -D %{S:9} %{buildroot}%{_sysconfdir}/sysconfig/%{name}


%check
%go_vendor_license_check -c %{S:3}


%pre
%sysusers_create_compat %{S:8}


%post
%systemd_post %{name}.service


%preun
%systemd_preun %{name}.service


%postun
%systemd_postun_with_restart %{name}.service


%files -f %{go_vendor_license_filelist}
%doc CONTRIBUTING.md README.md RELEASE-NOTES.md
%doc custom/conf/app.example.ini

%{_bindir}/%{name}

%dir %{_sysconfdir}/%{name}
%dir %{_sysconfdir}/%{name}/conf
%dir %{_sysconfdir}/%{name}/public
%dir %{_sysconfdir}/%{name}/public/assets
%dir %{_sysconfdir}/%{name}/templates
%{_sysconfdir}/%{name}/conf/app.ini.tmpl
%attr(0640,-,%{name}) %ghost %config(missingok) %{_sysconfdir}/%{name}/conf/app.ini
%config(noreplace) %{_sysconfdir}/%{name}/public/robots.txt
%config(noreplace,missingok) %{_sysconfdir}/sysconfig/%{name}

%{_sysusersdir}/%{name}.conf
%{_datadir}/bash-completion/completions/%{name}
%{_unitdir}/%{name}.service
%{_unitdir}/%{name}-init.service
%{_libexecdir}/%{name}-init

%attr(0750,%{name},%{name}) %dir %{_sharedstatedir}/%{name}
%attr(0750,%{name},%{name}) %dir %{_sharedstatedir}/%{name}/data
%attr(0750,%{name},%{name}) %dir %{_sharedstatedir}/%{name}/log

%changelog
## START: Generated by rpmautospec
* Fri Apr 25 2025 Nils Philippsen <nils@tiptoe.de> - 11.0.0-1
- Uncommitted changes
## END: Generated by rpmautospec
